@@ -14,6 +14,7 @@ from suite_py.commands.delete_qa import DeleteQA
 from suite_py.commands.release import Release
 from suite_py.commands.deploy import Deploy
 from suite_py.commands.generator import Generator
+from suite_py.commands.id import ID
 from suite_py.commands.ip import IP
 from suite_py.commands.merge_pr import MergePR
 from suite_py.commands.open_pr import OpenPR
@@ -159,6 +160,13 @@ def cli_check(obj):
     Check(obj["config"], obj["tokens"]).run()
 
 
+@main.command("id", help="Get the ID of the hosts where the task is running")
+@click.argument("environment", type=click.Choice(("staging", "production")))
+@click.pass_obj
+def cli_id(obj, environment):
+    ID(obj["project"], environment).run()
+
+
 @main.command("ip", help="Get the IP addresses of the hosts where the task is running")
 @click.argument("environment", type=click.Choice(("staging", "production")))
 @click.pass_obj
