@@ -18,7 +18,7 @@ class CreateBranch:
 
     def run(self):
         if self._git.is_dirty():
-            logger.error("Hai modifiche non committate, non posso continuare")
+            logger.error("You have some uncommited changes, I can't continue")
             sys.exit(-1)
 
         try:
@@ -28,7 +28,7 @@ class CreateBranch:
                 issue = self._youtrack.get_issue(self._ask_card())
         except Exception:
             logger.error(
-                "Si e' verificato un problema recuperando la issue da youtrack. Controlla che il numero della issue e' corretto"
+                "There was a problem retrieving the issue from YouTrack. Check that the issue number is correct"
             )
             sys.exit(-1)
 
@@ -40,13 +40,13 @@ class CreateBranch:
 
     def _ask_card(self):
         return prompt_utils.ask_questions_input(
-            "Inserisci il numero della issue youtrack:",
+            "Insert the YouTrack issue number:",
             self._config.user["default_slug"],
         )
 
     def _checkout_branch(self, issue):
         branch_name = prompt_utils.ask_questions_input(
-            "Inserisci nome del branch: ",
+            "Enter branch name: ",
             re.sub(
                 r'([\s\\.,~\^:\(\)\[\]\<\>"\'?]|[^\x00-\x7F]|[0-9])+',
                 "-",
@@ -59,7 +59,7 @@ class CreateBranch:
         )
 
         parent_branch_name = prompt_utils.ask_questions_input(
-            "Inserisci branch iniziale: ", default_parent_branch_name
+            "Insert initial branch: ", default_parent_branch_name
         )
 
         branch_type = issue["Type"].lower().replace(" ", "-")
