@@ -50,7 +50,7 @@ class GitHandler:
                 )
                 self.pull(rebase=True)
         except (CalledProcessError) as e:
-            logger.error(f"Errore eseguendo il comando: {e}")
+            logger.error(f"Error during command execution: {e}")
             sys.exit(-1)
 
     def commit(self, commit_message="", dummy=False):
@@ -72,14 +72,14 @@ class GitHandler:
                     stderr=subprocess.DEVNULL,
                 )
         except (CalledProcessError) as e:
-            logger.error(f"Errore eseguendo il comando: {e}")
+            logger.error(f"Error during command execution: {e}")
             sys.exit(-1)
 
     def add(self):
         try:
             subprocess.run(["git", "add", "."], cwd=self._path, check=True)
         except (CalledProcessError) as e:
-            logger.error(f"Errore eseguendo il comando: {e}")
+            logger.error(f"Error during command execution: {e}")
             sys.exit(-1)
 
     def push(self, branch, remote="origin"):
@@ -93,7 +93,7 @@ class GitHandler:
                     stderr=subprocess.DEVNULL,
                 )
             except (CalledProcessError) as e:
-                logger.error(f"Errore eseguendo il comando: {e}")
+                logger.error(f"Error during command execution: {e}")
                 sys.exit(-1)
 
     def pull(self, rebase=False):
@@ -116,7 +116,7 @@ class GitHandler:
                         stderr=subprocess.DEVNULL,
                     )
             except (CalledProcessError) as e:
-                logger.error(f"Errore eseguendo il comando: {e}")
+                logger.error(f"Error during command execution: {e}")
                 sys.exit(-1)
 
     def fetch(self, remote="origin"):
@@ -137,7 +137,7 @@ class GitHandler:
                     stderr=subprocess.DEVNULL,
                 )
             except (CalledProcessError) as e:
-                logger.error(f"Errore eseguendo il comando: {e}")
+                logger.error(f"Error during command execution: {e}")
                 sys.exit(-1)
 
     def sync(self):
@@ -147,9 +147,7 @@ class GitHandler:
 
     def check_repo_cloned(self):
         if self._repo not in os.listdir(self._projects_home):
-            logger.warning(
-                "Il progetto non e' presente nella tua home dei progetti, lo clono adesso.."
-            )
+            logger.warning("The project is not in your home path, cloning it now...")
             self.clone()
 
     def delete_remote_branch(self, branch):
@@ -213,7 +211,7 @@ class GitHandler:
             ).stdout.decode("utf-8")
             return re.sub("\n", "", output)
         except (CalledProcessError) as e:
-            logger.error(f"Errore eseguendo il comando: {e}")
+            logger.error(f"Error during command execution: {e}")
             sys.exit(-1)
 
     def is_dirty(self):
@@ -227,7 +225,7 @@ class GitHandler:
 
             return len(output) != 0
         except (CalledProcessError) as e:
-            logger.error(f"Errore eseguendo il comando: {e}")
+            logger.error(f"Error during command execution: {e}")
             sys.exit(-1)
 
     def reset(self):
@@ -238,7 +236,7 @@ class GitHandler:
                 check=True,
             )
         except CalledProcessError as e:
-            logger.error(f"Errore eseguendo git reset su {self._repo}: {e}")
+            logger.error(f"Error during git reset on {self._repo}: {e}")
             sys.exit(-1)
 
 
